@@ -4,7 +4,6 @@ from palm.plugins.dbt.dbt_palm_utils import shell_options, dbt_env_vars
 
 
 @click.command("run")
-@click.option("--fast", is_flag=True, help="will skip clean/deps/seed")
 @click.option(
     "--no-fail-fast",
     is_flag=True,
@@ -27,7 +26,6 @@ from palm.plugins.dbt.dbt_palm_utils import shell_options, dbt_env_vars
 @click.pass_context
 def cli(
     ctx,
-    fast: bool,
     no_fail_fast: bool,
     persist: bool,
     full_refresh: bool,
